# nrobust

A set of packages for a robust, certain and stable model space.

Note: At the minute its best ran from something like `python -m src.nrobust.playground.py`!

@TODO next: implement weighting and selection over the loaded outcome spaces